@@ -1,12 +1,12 @@
 import argparse
 from tweetcapture import TweetCapture
 from asyncio import run
-
+import traceback
 
 def parse_args():
     parser = argparse.ArgumentParser(description='Take a tweet screenshot.')
     parser.add_argument('url', type=str, help="Tweet URL")
-    parser.add_argument('-m', "--mode", type=int, help="Mods to show/hide some tweet items (0-3)", default=0)
+    parser.add_argument('-m', "--mode", type=int, help="Mods to show/hide some tweet items (0-3)", default=3)
     parser.add_argument('-t', type=float, help="Waiting time while the page loading (1.0-10.0)", default=5.0)
     parser.add_argument("-n", "--night-mode", type=int, help="Twitter night mode theme (0-2)", default=0)
     parser.add_argument('--lang', type=str,help="Browser language code (tr,en,es,..)", default="")
@@ -30,5 +30,8 @@ def main():
     if len(args.chromedriver) > 0:
         tweet.set_chromedriver_path(args.chromedriver)
     tweet.Fake.create(args.fake_name, args.fake_content, args.fake_username, args.fake_image, args.fake_verified)
-    filename = run(tweet.screenshot(args.url, args.output))
-    print(f"Screenshot is saved: {filename}")
+    try:
+        filename = run(tweet.screenshot(args.url, args.output))
+        print(f"Screenshot is saved: {filename}")
+    except Exception as error:
+        traceback.print_exc()
