@@ -1,5 +1,7 @@
 from selenium import webdriver
 from selenium.webdriver.chrome.options import Options
+from selenium.webdriver.chrome.service import Service
+from webdriver_manager.chrome import ChromeDriverManager
 
 
 async def get_driver(custom_options=None, driver_path=None):
@@ -11,6 +13,7 @@ async def get_driver(custom_options=None, driver_path=None):
     chrome_options.add_argument("--disable-dev-shm-usage")
     chrome_options.add_argument("--window-size=768,2000");
     chrome_options.add_argument("--remote-debugging-port=9222")
+    chrome_options.add_argument("user-agent=Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/103.0.0.0 Safari/537.36")
 
     if isinstance(custom_options, list) and len(custom_options) > 0:
         for option in custom_options:
@@ -19,7 +22,6 @@ async def get_driver(custom_options=None, driver_path=None):
     chrome_options.add_experimental_option(
         'excludeSwitches', ['enable-logging'])
 
-    driver = webdriver.Chrome(
-        executable_path=driver_path, options=chrome_options)
+    driver = webdriver.Chrome(service=Service(ChromeDriverManager().install()), options=chrome_options)
 
     return driver
